package com.example.ellegadodepintia

import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.util.DisplayMetrics
import android.view.View
import android.widget.ImageButton
import android.widget.RelativeLayout
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import com.example.ellegadodepintia.exploradoresDePintia.ExploradoresDePintia
import com.example.ellegadodepintia.exploradoresDePintia.model.GameState


class MapActivity : AppCompatActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_map)
        GameState.jugador.addObserver { actualizarMonedas() }
        ajustarPosiciones()
        val mapButton: ImageButton= findViewById(R.id.mapButton)
        val leaderboardButton: ImageButton = findViewById(R.id.leaderboardButton)
        val shopButton: ImageButton = findViewById(R.id.shopButton)

        leaderboardButton.setOnClickListener{
            val intent = Intent(this, LeaderboardActivity::class.java)
            startActivity(intent)
        }

        actualizarMonedas()

        mapButton.setBackgroundResource(R.drawable.style_texto_border)
        leaderboardButton.setBackgroundColor(Color.TRANSPARENT)
        shopButton.setBackgroundColor(Color.TRANSPARENT)

        val aventura = findViewById<ImageButton>(R.id.botonAventura)
        aventura.setOnClickListener {
            val intent = Intent(this, ExploradoresDePintia::class.java)
            startActivity(intent)
        }

        val taberna = findViewById<ImageButton>(R.id.botonTaberna)
        taberna.setOnClickListener {
            val intent = Intent(this, TabernaActivity::class.java)
            startActivity(intent)
        }

        val tienda = findViewById<ImageButton>(R.id.botonTienda)
        tienda.setOnClickListener {
            val intent = Intent(this, TiendaActivity::class.java)
            startActivity(intent)
        }

        val armeria = findViewById<ImageButton>(R.id.botonArmeria)
        armeria.setOnClickListener {
            val intent = Intent(this, ArmeriaActivity::class.java)
            startActivity(intent)
        }
    }

    private fun actualizarMonedas(){
        GameState.jugador.monedas.toString().also { findViewById<TextView>(R.id.moneyText).text = it }
    }

    private fun ajustarPosiciones() {
        // Dimensiones de la pantalla original
        val originalWidth = 1080f
        val originalHeight = 2285f

        // Obtener las dimensiones actuales de la pantalla
        val displayMetrics = DisplayMetrics()
        windowManager.defaultDisplay.getMetrics(displayMetrics)
        val currentWidth = displayMetrics.widthPixels.toFloat()
        val currentHeight = displayMetrics.heightPixels.toFloat()
        val density = displayMetrics.density // Densidad de la pantalla actual

        // Calcular la proporción de la pantalla actual respecto a la original
        val widthRatio = currentWidth / originalWidth
        val heightRatio = currentHeight / originalHeight

        // Ajustar los botones con el ratio de proporción
        ajustarBoton(findViewById(R.id.botonAventura), 55f, 65f, 199f, 140f, widthRatio, heightRatio, density)
        ajustarBoton(findViewById(R.id.botonTaberna), 169f, 380f, 168f, 127f, widthRatio, heightRatio, density)
        ajustarBoton(findViewById(R.id.botonTienda), -1f, 422f, 148f, 127f, widthRatio, heightRatio, density)
        ajustarBoton(findViewById(R.id.botonArmeria), 199f, 540f, 192f, 145f, widthRatio, heightRatio, density)
        ajustarBoton(findViewById(R.id.botonEntrenar), 241f, 226f, 170f, 125f, widthRatio, heightRatio, density)
    }

    private fun ajustarBoton(
        button: View,
        originalX: Float,  // Margen Start original en dp
        originalY: Float,  // Margen Bottom original en dp
        originalWidth: Float,  // Ancho original en dp
        originalHeight: Float, // Alto original en dp
        widthRatio: Float,
        heightRatio: Float,
        density: Float
    ) {
        val params = button.layoutParams as RelativeLayout.LayoutParams

        // Ajustar las posiciones según el ratio de la pantalla
        val newMarginStart = (originalX * widthRatio * density).toInt() // Ajustamos la posición X
        val newBottomMargin = (originalY * heightRatio * density).toInt() // Ajustamos la posición Y (Bottom)

        // Ajustar el tamaño según el ratio de la pantalla
        val newWidth = (originalWidth * widthRatio * density).toInt()
        val newHeight = (originalHeight * heightRatio * density).toInt()

        // Establecer tamaños mínimos y máximos
        val minSizePx = (48 * density).toInt() // Tamaño mínimo de 48dp en píxeles
        val maxSizePx = (300 * density).toInt() // Tamaño máximo de 300dp en píxeles

        // Aplicar los nuevos márgenes y tamaños
        params.marginStart = newMarginStart
        params.bottomMargin = newBottomMargin
        params.width = newWidth.coerceIn(minSizePx, maxSizePx) // Tamaño mínimo y máximo
        params.height = newHeight.coerceIn(minSizePx, maxSizePx) // Tamaño mínimo y máximo

        // Aplicar los parámetros ajustados al botón
        button.layoutParams = params
    }



}
